pyxmpp2.sasl.plain

Package pyxmpp2 :: Package sasl :: Module plain |
[hide private]

# Module plain

PLAIN authentication mechanism for PyXMPP SASL implementation.

Normative reference:
  - RFC 4616

Classes | [hide private]
| PlainClientAuthenticator Provides PLAIN SASL authentication for a client.
| PlainServerAuthenticator Provides PLAIN SASL authentication for a server.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.sasl.plain")`